/****************************************************************************
**
** gfxlcd.h 
**
** Connections:
** ============
**
** 	   Parallelport			SED1335F0B
**
**	 1 - /STROBE	C0-		/WR - 14
**	 2 - DATA0	D0		 D0 - 22
**	 3 - DATA1	D1		 D1 - 23
**	 4 - DATA2	D2		 D2 - 24
**	 5 - DATA3	D3		 D3 - 25
**	 6 - DATA4	D4		 D4 - 26
**	 7 - DATA5	D5		 D5 - 27
**	 8 - DATA6	D6		 D6 - 28
**	 9 - DATA7	D7		 D7 - 29
**	14 - /FEED	C1-		 A0 - 20
**	16 - /RESET	C2+		/RD - 13
**	17 - /SELOUT	C3-		/CS - 19
**
** The SED1335 has to be in 8080 mode by pulling SEL1, SEL2 to ground. 
**
*****************************************************************************/

#define BASE	0x378	/* parallel port base address */
#define DATA	BASE
#define STATUS	BASE+1
#define CONTROL	BASE+2


#define CURSOR_ON 1
#define BLINK_ON 2


typedef unsigned char u8;
typedef unsigned short u16;

static u8 lcd_display_mode = 0x16;

static int debug = 1;
static u16 LCD_TEXT_ADDRESS = 0x0000;
static u16 LCD_GFX_ADDRESS  = 0x04b0;
static int LCD_TEXT_ROWS    = 30;
static int LCD_TEXT_COLS    = 40;

static u8 CTRL_CFL_ON  = 2;
static u8 CTRL_CFL_OFF = 3;

static u8 *fmap = NULL;		/* buffer for image */

/* /WR = /STROBE (Pin 1) */
#define WRHI	outb(inb(CONTROL) & 0xfe, CONTROL)
#define WRLO	outb(inb(CONTROL) | 0x01, CONTROL)

/* A0 = /FEED (Pin 14) */
#define A0HI	outb(inb(CONTROL) & 0xfd, CONTROL)
#define A0LO	outb(inb(CONTROL) | 0x02, CONTROL)

/* /RD = /RESET (Pin 16) */
#define RDHI	outb(inb(CONTROL) | 0x04, CONTROL)
#define RDLO	outb(inb(CONTROL) & 0xfb, CONTROL)

/* /CS = /SELOUT (Pin 17) */
#define CSHI	outb(inb(CONTROL) & 0xf7, CONTROL)
#define CSLO	outb(inb(CONTROL) | 0x08, CONTROL)

/* Data input direction */
#define DATAIN	outb(inb(CONTROL) | 0x20, CONTROL)
#define DATAOUT	outb(inb(CONTROL) & 0xdf, CONTROL)

#define POSITION(x,y)  ((y)*LCD_TEXT_COLS + (x))
#define A_POSITION(x,y)  ((y*8)*LCD_TEXT_COLS + (x))

/* ncurses */

WINDOW *mainw;
WINDOW *keyw;
WINDOW *logw;
WINDOW *statw;

/* function prototypes */
char* dec2bin(int dec, char *bin);
void prbin(char *text, int dec);
void setc(unsigned int);
void clrc(unsigned int);
void logit(char *text);
void lcd_write_cmd(u8 command);
u8 lcd_read_byte(void);
void lcd_write_command(u8 command, int plen, u8 parameter[]);
void lcd_write_data(u8 databyte);
void lcd_clear_text(void);
void lcd_write_image(int size);
void lcd_write_text(int tx, int ty, char *text);
void lcd_set_gfx_csr(int x, int y);
int loadimage(char *file);
void lcd_init(void);
void lcd_console(void);
void ext_ctrl(u8 cmd);
void ext_reset(void);
void finish(int sig);

